Public CLI primitives for implementation-first command trees, parsed strategy dispatch, and strategy error types.
Structs
- Argument
- Argument
Definition - Command
- Metadata + handler pair for a single CLI command.
- Command
Builder - Fluent command builder that hides strategy implementation details.
- Command
Meta Data - User-facing metadata for a single CLI command.
- Function
Strategy - Adapter that turns a function or closure into a
CommandStrategy. - Strategy
Error - Structured error returned by
super::CommandStrategy::execute. - Subcommand
Router - Strategy helper implementing chain-of-responsibility style subcommand dispatch.
- Switch
Definition - Declarative value-taking option metadata.
Enums
- Argument
Value - Strategy
Error Kind - Categorizes strategy failures for downstream error handling.
- Value
Type
Traits
- Command
Strategy - Strategy contract for CLI command implementations.
- Subcommand
Catalog - Optional help-time capability exposed by strategies that can route to child strategies.
Functions
- argument
- creates a value-taking option declaration.
- argument_
of_ type - command
- Creates a fluent command builder.
- switch
- creates a value-taking option declaration with the required flag set to true.